% this function reads the output and generate the results
% 8/2/2024
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc
clear

%% Parameters
load('Results_DQN')
% reset the agent saving criteria if saved too much
OptIndex = find(trainingStats.EpisodeReward > 1.2e4);
P_max = 0;
% 29 is optimal validated
for i = 1:length(OptIndex)

    % Try the agent number if it exist
    agentNum = OptIndex(i);
    try
        % load the agent
        load(['run\Agents\Agent',num2str(agentNum),'.mat'],'saved_agent'); %1502
        agent = saved_agent;

        %% Simulate DQN Agent
        T_f = 600;
        % rng(0)
        simOptions = rlSimulationOptions('MaxSteps',ceil(T_f/T_s),'SimulationStorageType','file');
        % experience returns as a structure varialbe which contains simulation
        % results
        exp = sim(env,agent,simOptions);

        % compute the mean power output
        load('savedSims\SimulationInfo1.mat')
        P_vec_temp = squeeze(SimulationInfo.P_vec.signals.values);
        P_mean = mean(P_vec_temp(30001:end));  % Average Power after 30s
    catch
        fprintf('No agent\n')
        P_mean = 0;
    end
    % save the maximum power
    if P_mean > P_max
        P_max = P_mean;
        OptAgentNum = agentNum;
    end
end


figure
plot(SimulationInfo.P_vec.time,squeeze(SimulationInfo.P_vec.signals.values),'linewidth',1.5)
hold on
plot(exp.Reward.time,exp.Reward.Data,'linewidth',1.5)
xlabel('Time(s)')
ylabel('Power')
legend('Power','Reward')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on

% figure
% plot(exp.SimulationInfo.P_vec.time,exp.SimulationInfo.P_vec.signals.values,'linewidth',1.5)
% hold on
% plot(trainingStats.SimulationInfo(agentNum,1).P_vec.time,trainingStats.SimulationInfo(agentNum,1).P_vec.signals.values,'linewidth',1.5)
% xlabel('Time(s)')
% ylabel('Power')
% legend('Validation','Training')
% set(gca,'Fontsize',18,'FontWeight','bold')
% grid on

figure
plot(SimulationInfo.P_vec.time,cumsum(squeeze(SimulationInfo.P_vec.signals.values))*dt,'linewidth',1.5)
hold on
plot(exp.Reward.time,cumsum(exp.Reward.Data)*T_s,'linewidth',1.5)
ylabel('Accumulated Reward')
legend('Power','Reward')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on

figure
plot(SimulationInfo.z_vec.time,SimulationInfo.z_vec.signals.values,'linewidth',1.5)
xlabel('Time(s)')
ylabel('displacement (m)')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on

figure
plot(SimulationInfo.v_vec.time,SimulationInfo.v_vec.signals.values,'linewidth',1.5)
xlabel('Time(s)')
ylabel('velocity (m/s)')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on

dK_vec = squeeze(SimulationInfo.a_vec.signals.values);
t_vec = SimulationInfo.a_vec.time;

figure
plot(t_vec,dK_vec(1,:),'linewidth',1.5)
xlabel('Time(s)')
ylabel('delt Ki')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
figure
plot(t_vec,dK_vec(2,:),'linewidth',1.5)
xlabel('Time(s)')
ylabel('delt Kp')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on


figure
plot(SimulationInfo.Ki_vec.time,squeeze(SimulationInfo.Ki_vec.signals.values),'linewidth',1.5)
xlabel('Time(s)')
ylabel('Ki')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on

figure
plot(SimulationInfo.Kp_vec.time,squeeze(SimulationInfo.Kp_vec.signals.values),'linewidth',1.5)
xlabel('Time(s)')
ylabel('Kp')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on

figure
plot(SimulationInfo.F_PTO.time,squeeze(SimulationInfo.F_PTO.signals.values),'linewidth',1.5)
xlabel('Time(s)')
ylabel('F PTO')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on




