% this function is the general deployment function
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc
clear

%% General Parameters
T_f = 600;  % consistent with simulation final time
T_s = 0.5;  % agent sample time (note which is different compared
% to simulation time step which is directly specified in Simulink) 
dt = 0.01; % s, it is noted that this is the simulation step

%% Configurate WEC-Sim
% Initialize WEC-Sim
SimFileName = 'Sim_DRL_LUPA_ver3';
Hs = 0.15;
Tp = 1.75;
run('wecSimInputFile');
clear simu waves body cable pto constraint ptoSim mooring 
runWecSimCML = 1;
run('initializeWecSim');

%% Deployment
load(['BestAgent\AgentHs',num2str(0.15*100),'_Tp',num2str(1.75*100),'_1.mat'],'saved_agent');
agent = saved_agent;
% generate .mat agent data
generatePolicyBlock(agent);
bdclose('untitled')
Ki0 = -1000;
Kp0 = 200;
Ki_max = 0;
Ki_min = -7e3;
Kp_max = 3000;
Kp_min = 0;
C_Pto = 600;
R_seed = floor(1000*rand(1,1));
T_thres = 12+ 2*rand(1,1);
T_min = 100 + floor(160*rand(1,1));
T_max = T_min + 4 + floor(6*rand(1,1));
M_z = 0.7*floor(0.5 + rand(1,1)) + 0.5 + 0.3*rand(1,1);

%% Run model
tic
sim('Sim_DRL_LUPA_ver3')
toc
% delete block agent data after Simulation
delete blockAgentData.mat

%% Plot the results
figure
plot(z_vec.time,z_vec.signals.values,'linewidth',1.5)
xlabel('Time(s)')
ylabel('Displacement (m)')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
figure
plot(v_vec.time,v_vec.signals.values,'linewidth',1.5)
xlabel('Time(s)')
ylabel('Vel (m/s)')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
figure
plot(K_p.time,squeeze(K_p.signals.values),'linewidth',1.5)
xlabel('Time(s)')
ylabel('K_p')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
figure
plot(K_i.time,squeeze(K_i.signals.values),'linewidth',1.5)
xlabel('Time(s)')
ylabel('K_i')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on

Pow = -squeeze(F_PTO.signals.values).*v_vec.signals.values;
Ene = cumsum(Pow)*dt;
figure
plot(F_PTO.time,Ene,'linewidth',1.5)
xlabel('Time(s)')
ylabel('Energy (J)')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on

























