% this function reads the output and generate the results
% 8/2/2024
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc
clear

%% Parameters
load('Results_DQN')
Rew_max = -1000;
OptAgentNum1 = [];
OptAgentNum2 = [];
OptIndex = find(trainingStats.EpisodeReward > 5e3);
for i = 1:length(OptIndex)

    % Try the agent number if it exist
    agentNum = OptIndex(i);
    try
        % load the agent
        load(['run\Agents\Agent',num2str(agentNum),'.mat'],'saved_agent'); %1502
        agent = saved_agent;

        %% Simulate DQN Agent
        T_f = 400;
        % rng(0)
        simOptions = rlSimulationOptions('MaxSteps',ceil(T_f/T_s),'SimulationStorageType','file');
        % experience returns as a structure varialbe which contains simulation
        % results
        exp = sim(env,agent,simOptions);

        % compute the mean power output
        load('savedSims\SimulationInfo1.mat')
        Rew_vec_temp = squeeze(SimulationInfo.Rew_vec.signals.values);
        Rew_mean = mean(Rew_vec_temp(10001:end));  % Average Power after 30s
        Ki_vec = squeeze(SimulationInfo.Ki_vec.signals.values);
        Kp_vec = squeeze(SimulationInfo.Kp_vec.signals.values);
        Ki_acc = Ki_vec + 7000;
        Kp_acc = Kp_vec - 3000;
    catch
        fprintf('No agent\n')
        Rew_mean = 0;
        Ki_acc = 0;
        Kp_acc = 0;
    end
    % save the maximum power
    if Rew_mean > Rew_max
        Rew_max = Rew_mean;
        OptAgentNum = agentNum;
    end
    if sum(Ki_acc(30001:end)) ~= 0
        OptAgentNum1 = [OptAgentNum1;agentNum];
    end
    if sum(Kp_acc(30001:end)) ~= 0
        OptAgentNum2 = [OptAgentNum2;agentNum];
    end
end

%%
figure
plot(SimulationInfo.P_vec.time,squeeze(SimulationInfo.P_vec.signals.values),'linewidth',1.5)
hold on
plot(exp.Reward.time,exp.Reward.Data,'linewidth',1.5)
xlabel('Time(s)')
ylabel('Power')
legend('Power','Reward')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
% figure
% plot(exp.SimulationInfo.P_vec.time,exp.SimulationInfo.P_vec.signals.values,'linewidth',1.5)
% hold on
% plot(trainingStats.SimulationInfo(agentNum,1).P_vec.time,trainingStats.SimulationInfo(agentNum,1).P_vec.signals.values,'linewidth',1.5)
% xlabel('Time(s)')
% ylabel('Power')
% legend('Validation','Training')
% set(gca,'Fontsize',18,'FontWeight','bold')
% grid on
figure
plot(SimulationInfo.P_vec.time,cumsum(squeeze(SimulationInfo.P_vec.signals.values))*dt,'linewidth',1.5)
hold on
plot(exp.Reward.time,cumsum(exp.Reward.Data)*T_s,'linewidth',1.5)
ylabel('Accumulated Reward')
legend('Power','Reward')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
figure
plot(SimulationInfo.z_vec.time,SimulationInfo.z_vec.signals.values,'linewidth',1.5)
xlabel('Time(s)')
ylabel('displacement (m)')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
figure
plot(SimulationInfo.v_vec.time,SimulationInfo.v_vec.signals.values,'linewidth',1.5)
xlabel('Time(s)')
ylabel('velocity (m/s)')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
dK_vec = squeeze(SimulationInfo.a_vec.signals.values);
t_vec = SimulationInfo.a_vec.time;
figure
plot(t_vec,dK_vec(1,:),'linewidth',1.5)
xlabel('Time(s)')
ylabel('delt Ki')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
figure
plot(t_vec,dK_vec(2,:),'linewidth',1.5)
xlabel('Time(s)')
ylabel('delt Kp')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
figure
plot(SimulationInfo.Ki_vec.time,squeeze(SimulationInfo.Ki_vec.signals.values),'linewidth',1.5)
xlabel('Time(s)')
ylabel('Ki')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
figure
plot(SimulationInfo.Kp_vec.time,squeeze(SimulationInfo.Kp_vec.signals.values),'linewidth',1.5)
xlabel('Time(s)')
ylabel('Kp')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on
figure
plot(SimulationInfo.F_PTO.time,squeeze(SimulationInfo.F_PTO.signals.values),'linewidth',1.5)
xlabel('Time(s)')
ylabel('F PTO')
set(gca,'Fontsize',18,'FontWeight','bold')
grid on